#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monads-tf
version:              0.3.0.1
visibility:           public
id:                   monads-tf-0.3.0.1-Iu8LT2HmoyzIomyBGSfa1u
key:                  monads-tf-0.3.0.1-Iu8LT2HmoyzIomyBGSfa1u
license:              BSD-3-Clause
maintainer:
    Ross Paterson <ross@soi.city.ac.uk>,
    Chris Martin <chris@typeclasses.com>

author:               Andy Gill
homepage:             https://github.com/typeclasses/monads-tf
synopsis:             Monad classes, using type families
description:
    Monad classes using type families, with instances for
    various monad transformers.

category:             Control
abi:                  00d5ca6db08ea4842ce7ad3d688e392d
exposed:              True
exposed-modules:
    Control.Monad.Cont Control.Monad.Cont.Class Control.Monad.Except
    Control.Monad.Except.Class Control.Monad.Identity Control.Monad.RWS
    Control.Monad.RWS.Class Control.Monad.RWS.Lazy
    Control.Monad.RWS.Strict Control.Monad.Reader
    Control.Monad.Reader.Class Control.Monad.State
    Control.Monad.State.Class Control.Monad.State.Lazy
    Control.Monad.State.Strict Control.Monad.Trans Control.Monad.Writer
    Control.Monad.Writer.Class Control.Monad.Writer.Lazy
    Control.Monad.Writer.Strict

import-dirs:          /usr/lib/ghc-9.6.6/site-local/monads-tf-0.3.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/monads-tf-0.3.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/monads-tf-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monads-tf
hs-libraries:         HSmonads-tf-0.3.0.1-Iu8LT2HmoyzIomyBGSfa1u
depends:              base-4.18.2.1 transformers-0.6.1.0
haddock-interfaces:   /usr/share/doc/haskell-monads-tf/html/monads-tf.haddock
haddock-html:         /usr/share/doc/haskell-monads-tf/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

